<textarea id="source">
{{ markdown }}
</textarea>

<script src="{{ engine_root }}/remark.min.js" type="text/javascript"></script>

<script type="text/javascript">
  var slideshow = remark.create();
</script>
