<!doctype html>
<html>
  <head>
    <meta charset="utf-8" />
    <meta name="keywords" content="cicero,markdown,slideshow,presentation" />
    <meta name="description" content="cicero.xyz: serving slides written in markdown." />
    <link rel="icon" type="image/png" href="{{ url_for('static', filename='img/icon.png') }}" />
    <title>{{ title }}</title>

    {{ custom_head_html }}
    <style>
      {{ custom_css }}
    </style>
  </head>

  <body>
    {{ custom_body_html }}
  </body>
</html>
